#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Information
==================

pyarubaimc is a python binding for working with Aruba IMC 7.3 or greater.

Copyright (c) 2022 Aruba, a Hewlett Packard Enterprise company

version 0.1.2 - beta.
"""
from pyarubaimc import (auth, objects)
